<?php

/**
 * @file
 * Admin menu callbacks.
 */

/* require_once libraries_get_path('faker') . '/src/autoload.php'; */

/**
 * Settings form for general competition configuration.
 */
function mask_user_data_settings() {
  $form = array();

  $form['mask_user_data_enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enabled'),
    '#description' => t('<b>Only enable this if you are on a 
      non-production site</b>. The process is not reversible and you might lose 
      sensitive data.<br />
      For production, it is strongly recommended to load this value from the 
      <em>settings.php</em> file like: 
      <em>$conf[\'mask_user_data_enabled\'] = FALSE;</em>
      <br /><br />
      Data masking process can be triggered via drush: <b>drush mud</b><br />
      Or else it will run via <b>cron</b> hook.
    '),
    '#default_value' => variable_get('mask_user_data_enabled', FALSE),
  );

  $map_array = variable_get('mask_user_data_map_array', NULL);
  $map_json = $map_array ? json_encode($map_array) : '';
  $form['mask_user_data_map'] = array(
    '#type' => 'textarea',
    '#title' => t('Map'),
    '#description' => t('Provide a valid JSON string where the keys are
      the field names and the values are the <a target="_blank" href="https://github.com/fzaninotto/Faker#formatters">Faker functions</a>. <br/>
      Example:
      <em>{ "mail": "email", "field_job_title": "jobTitle" }</em>.<br /><br />
      * If the string is not valid JSON then no data masking will be performed,
      or if it is valid but contains invalid field names, properties or 
      functions then those invalid ones will not be masked.
    '),
    '#default_value' => $map_json,
    '#states' => array(
      'invisible' => array(
        ':input[name="mask_user_data_enabled"]' => array('checked' => FALSE),
      ),
    ),
  );

  if (
    variable_get('mask_user_data_enabled', FALSE) &&
    variable_get('mask_user_data_already_masked') !== TRUE
  ) {
    $map_array = variable_get('mask_user_data_map_array', NULL);
    if (!(empty($map_array) || !is_array($map_array))) {
      $form['actions']['mask_data'] = array(
        '#type' => 'submit',
        '#value' => t('Mask data now'),
        '#submit' => ['_mask_data_now'],
        '#weight' => 10,
      );
    }
  }
  elseif (
    variable_get('mask_user_data_enabled', FALSE) &&
    variable_get('mask_user_data_already_masked') === TRUE
  ) {
    $form['info'] = [
      '#markup' => t('<b style="color:mediumseagreen">The data has already been masked.</b>'),
    ];
  }

  /*
  TODO: dynamic form ready from user properties and fields that will offer
  a dropdown per field with the Faker functions available to use.
  It will generate a JSON mapping replacing the previous textarea.
   */

  $form['#submit'][] = '_mask_user_data_generate_array';
  return system_settings_form($form);
}

/**
 * Submit callback.
 */
function _mask_data_now() {
  mask_user_data_setup_batch();
}

/**
 * Submit callback.
 */
function _mask_user_data_generate_array($form, &$form_state) {
  if (!empty($form_state['values']['mask_user_data_map'])) {
    $prev_map_array = variable_get('mask_user_data_map_array', NULL);
    $prev_map_json = $prev_map_array ? json_encode($prev_map_array) : '';

    $map = $form_state['values']['mask_user_data_map'];
    $map_array = json_decode($map, TRUE);
    variable_set('mask_user_data_map_array', $map_array);

    if ($prev_map_json !== json_encode($map_array)) {
      variable_set('mask_user_data_already_masked', FALSE);
    }
  }
  else {
    variable_set('mask_user_data_map_array', NULL);
  }
}
